@@ -305,7 +305,13 @@ parser_styling_group.add_argument(
     "--no-today", action="store_true", help="don't add a 'today' line"
 )
 parser_styling_group.add_argument(
-    "--stacked", help="stacked bar chart", action="store_true"
+    "--stacked",
+    nargs="?",
+    choices={"zero", "sym", "wiggle", "weighted_wiggle"},
+    help="stacked chart. Can be used with --barplot. "
+    f"If an argument is given, it's the baseline style.",
+    default=False,
+    const="zero",
 )
 parser_styling_group.add_argument(
     "--barplot",
@@ -421,9 +427,10 @@ parser_modify_group.add_argument(
     default=[],
 )
 parser_modify_group.add_argument(
-    "--drop",
+    "--remove",
     metavar="REGEX",
     help="regular expressions for dropping columns right before plotting. "
+    "(Was previously called --drop, but that conflicted with hledger's --drop option.) "
     "Can be specified multiple times.",
     action="append",
     type=regex,
@@ -451,6 +458,8 @@ parser_modify_group.add_argument(
     "you can leave start and/or end time out or specify 'today', but the colon (:) needs to stay. "
     "The interval is optional and defaults to 1. "
     "If you specify a reference date outside the given range, an extrapolation line will be added. "
+    "The environment variables HLEDGER_PLOT_TREND_MIN_DIGITS (2) "
+    "and HLEDGER_PLOT_TREND_MIN_PLACES (0) control the decimal places for the fit parameters."
     "Can be specified multiple times.",
     action="append",
     nargs="?",
@@ -478,7 +487,7 @@ parser_modify_group.add_argument(
     "--mod-order",
     metavar="LIST",
     default=str_with_index_list(
-        default := "rename invert sum multiply resample groupby mean trend drop only"
+        default := "rename invert sum multiply resample groupby mean trend remove only"
     ),
     help="List of modification steps like 'sum(1),rename(2),resample(1)' "
     "specifying the application order of modifiers. "
@@ -837,35 +846,6 @@ pip install windows-curses
             )
             sys.exit(1)
 
-    # some sane defaults for rcParams
-    plt.rcParams["legend.handlelength"] = 5
-    if len(data.columns) > 10:
-        plt.rcParams["legend.fontsize"] = "x-small"
-    elif len(data.columns) > 15:
-        plt.rcParams["legend.fontsize"] = "xx-small"
-    plt.rcParams["axes.grid"] = True
-    plt.rcParams["axes.axisbelow"] = True
-    # expand prop cycle
-    prop_cycle = plt.rcParams["axes.prop_cycle"]
-    if "linestyle" not in prop_cycle:
-        prop_cycle = (
-            cycler(linestyle=["solid", "dashed", "dotted"]) * prop_cycle
-        )
-    if "linewidth" not in prop_cycle:
-        lw = plt.rcParams.get("lines.linewidth", 2)
-        prop_cycle = (
-            cycler(linewidth=[lw, lw + 1, lw + 2, lw + 3]) * prop_cycle
-        )
-    plt.rcParams["axes.prop_cycle"] = prop_cycle
-    # logger.debug(f"{list(plt.rcParams['axes.prop_cycle']) = }")
-
-    # merge all --rcParams options
-    args.rcParams = functools.reduce(
-        lambda a, b: {**a, **b}, filter(bool, args.rcParams), dict()
-    )
-    # overwrite with user's rcParams
-    plt.rcParams.update(args.rcParams)
-
     # 🔢 Data Modification
     def invert_handler(patterns, data=data):
         for pattern in patterns:
@@ -957,6 +937,8 @@ pip install windows-curses
 
         return data
 
+    added_trend_columns = []
+
     def trend_handler(trenddefs, data=data):
         for trenddef in trenddefs:
             logger.debug(f"{trenddef = }")
@@ -976,10 +958,19 @@ pip install windows-curses
                     ),
                     1,
                 )
-            if cols_to_fit := list(filter(pattern.search, data)):
+            if cols_to_fit := [
+                c
+                for c in filter(pattern.search, data)
+                if c not in added_trend_columns
+            ]:
                 for col in cols_to_fit:
                     series = data.loc[timerange, col].dropna()
                     logger.debug(f"series = \n{series}")
+                    if not series.size:
+                        logger.warning(
+                            f"{col!r} has no data in period {timerange}, can't fit trend"
+                        )
+                        continue
                     if hasattr(series.index, "strftime"):
                         days_since_reference = (
                             series.index.map(pd.Timestamp.timestamp)
@@ -996,7 +987,27 @@ pip install windows-curses
                         )
 
                     def autofmt(x, showsign=False):
-                        digits = np.clip(2 - oma(x), 0, None)
+                        min_digits = handle_exception(
+                            2,
+                            lambda: int(
+                                os.environ.get(
+                                    "HLEDGER_PLOT_TREND_MIN_DIGITS", 2
+                                )
+                            ),
+                        )
+                        min_places = handle_exception(
+                            0,
+                            lambda: int(
+                                os.environ.get(
+                                    "HLEDGER_PLOT_TREND_MIN_PLACES", 0
+                                )
+                            ),
+                        )
+                        digits = np.clip(
+                            min_digits - oma(x),
+                            min_places,
+                            None,
+                        )
                         fmt = f"{{:{'+' if showsign else ''}.{digits}f}} {account_commodities.get(col,'')}"
                         return fmt.format(x)
 
@@ -1042,13 +1053,15 @@ pip install windows-curses
                         ],
                         axis="columns",
                     ).sort_index()
+                    # remember colname for later ignoring
+                    added_trend_columns.append(trend_colname)
             else:
                 logger.warning(
                     f"--trend pattern {pattern.pattern!r} didn't match any columns."
                 )
         return data
 
-    def drop_handler(mapping, data=data):
+    def remove_handler(mapping, data=data):
         for pattern in mapping:
             if columns := list(filter(pattern.search, data)):
                 data = data.drop(columns=columns)
@@ -1075,7 +1088,7 @@ pip install windows-curses
         rename=rename_handler,
         mean=mean_handler,
         multiply=multiply_handler,
-        drop=drop_handler,
+        remove=remove_handler,
         only=only_handler,
         resample=resample_handler,
         groupby=groupby_handler,
@@ -1100,10 +1113,15 @@ pip install windows-curses
                 modsteps = allmodsteps
             if modsteps:
                 logger.debug(f"Running {modname!r} steps {modsteps}")
-                data = handler(modsteps, data=data)
-                logger.debug(
-                    f"data after {modname!r} with steps {modsteps}:\n{data}"
-                )
+                try:
+                    data = handler(modsteps, data=data)
+                    logger.debug(
+                        f"data after {modname!r} with steps {modsteps}:\n{data}"
+                    )
+                except Exception as e:
+                    logger.error(
+                        f"Couln't apply {modname!r}:\n{type(e).__name__}: {e}"
+                    )
             elif index is not None:
                 logger.warning(f"No {modname!r} steps? ({index = })")
         else:
@@ -1142,10 +1160,45 @@ pip install windows-curses
         length=float(os.environ.get("HLEDGER_PLOT_XKCD_LENGTH", 100)),
         randomness=float(os.environ.get("HLEDGER_PLOT_XKCD_RANDOMNESS", 2)),
     ) if args.xkcd else nothing():
+
+        # 🎨 rcParams plot styling
+        # some sane defaults for rcParams
+        plt.rcParams["legend.handlelength"] = 5
+        # no scientific notation
+        plt.rcParams["axes.formatter.limits"] = (-1000, 1000)
+        if len(data.columns) > 10:
+            plt.rcParams["legend.fontsize"] = "x-small"
+        elif len(data.columns) > 15:
+            plt.rcParams["legend.fontsize"] = "xx-small"
+        plt.rcParams["axes.grid"] = True
+        plt.rcParams["axes.axisbelow"] = True
+        # expand prop cycle
+        prop_cycle = plt.rcParams["axes.prop_cycle"]
+        if "linestyle" not in prop_cycle:
+            prop_cycle = (
+                cycler(linestyle=["solid", "dashed", "dotted"]) * prop_cycle
+            )
+        if "linewidth" not in prop_cycle:
+            lw = plt.rcParams.get("lines.linewidth", 2)
+            prop_cycle = (
+                cycler(linewidth=[lw, lw + 1, lw + 2, lw + 3]) * prop_cycle
+            )
+        plt.rcParams["axes.prop_cycle"] = prop_cycle
+        # logger.debug(f"{list(plt.rcParams['axes.prop_cycle']) = }")
+
+        # merge all --rcParams options
+        args.rcParams = functools.reduce(
+            lambda a, b: {**a, **b}, filter(bool, args.rcParams), dict()
+        )
+        # overwrite with user's rcParams
+        plt.rcParams.update(args.rcParams)
+
         fig, ax = plt.subplots(num=args.title)
         if args.barplot:
             logger.warning(
-                f"Barplots are kind of limited right now and don't scale well."
+                f"Barplots are kind of limited right now, don't scale well and neglect --style. "
+                f"Consider dropping --barplot and using only --stacked, "
+                f"that'll do a stacked line plot"
             )
             if args.stacked:
                 data.drop(
@@ -1193,14 +1246,14 @@ pip install windows-curses
                         logger.debug(
                             f"after filling with prop_cycle: {plot_kwargs = }"
                         )
-                ax.plot(series.index, series, **plot_kwargs)
+                if not args.stacked:
+                    ax.plot(series.index, series, **plot_kwargs)
                 used_styles.append(only_prop_cycle(plot_kwargs))
                 if logger.getEffectiveLevel() < logging.DEBUG:
                     logger.debug(f"{used_styles = }")
 
             if not args.no_today:
-                ax.axvline(
-                    pd.to_datetime(datetime.datetime.now()),
+                plot_kwargs = dict(
                     alpha=0.2,
                     color="black",
                     linewidth=10,
@@ -1208,10 +1261,39 @@ pip install windows-curses
                     label="today",
                     zorder=-10,
                 )
+                for pattern, kwargs in args.style:
+                    if pattern.search("today"):
+                        plot_kwargs.update(kwargs)
+                ax.axvline(
+                    pd.to_datetime(datetime.datetime.now()), **plot_kwargs
+                )
+
+            if args.stacked:
+                prop_cycle = iter(plt.rcParams["axes.prop_cycle"])
+                data_for_stackplot = [
+                    data[col].dropna().values for col in data
+                ]
+                logger.debug(f"{data_for_stackplot = }")
+                ax.stackplot(
+                    data.index.values,
+                    *data_for_stackplot,
+                    colors=[
+                        (s.get("color") or next(prop_cycle).get("color"))
+                        for s in used_styles
+                    ],
+                    labels=list(data),
+                    baseline=args.stacked,
+                )
 
         if args.title:
             fig.suptitle(sanitize_text(args.title))
-        ax.set_title(sanitize_text(args.axtitle or " ".join(hledger_args)))
+        ax.set_title(
+            sanitize_text(
+                " ".join(hledger_args)
+                if args.axtitle is None
+                else args.axtitle
+            )
+        )
         if args.groupby:
             ax.set_xlabel(f"days within period")
         ax.set_ylabel(" ".join(f"[{sanitize_text(c)}]" for c in commodities))
